# == Define: apahce::vhost
#
# This class installs Apache Virtual Hosts
#
# === Parameters
#
# [*port*]     - The port to configure the host on.
# [*docroot*]  - The docroot for the virtual host.
# [*priority*] - The priority of the virtual host.
# [*template*] - The tempate to use to create vhost.
# [*name*]     - The virtual hosts name.
# [*webadmin*] - The name of the user that is used to control wesites.
#
# === Author
#
# Sampo Tyllilä <sampo.tyllila@gmail.com>
#
define apache::vhost ( 
	$port, 
	$docroot, 
	$priority, 
	$virtualhost = '*',
	$template = 'apache/vhost.conf.erb' 
) 	{

	include apache

	file { '/etc/apache2/sites-enabled/000-default':
		ensure => absent,
	}

        file { "/etc/apache2/sites-available/${name}":
		ensure  => file,
                content => template($template),
		owner   => 'root',
		group   => 'root',
		mode    => '0644',
                require => Class['apache::install'],
                notify  => Class['apache::service'],
         }

	file { "/etc/apache2/sites-enabled/${priority}-${name}":
		ensure  => link,
		target  => "/etc/apache2/sites-available/${name}",
		require => File["/etc/apache2/sites-available/${name}"],
	}

        file { "/home/${apache::params::webadmin}/${name}":
                ensure  => directory,
		replace => false,
                owner   => $apache::params::webadmin,
                group   => $apache::params::webadmin,
                mode    => '0644',
                require => Class['apache::webadmin'],
        }

        file { $docroot:
                ensure  => link,
                target  => "/home/${apache::params::webadmin}/${name}",
		require => File["/home/${apache::params::webadmin}/${name}"],
        }
}
