# == Define: rdiff::backup
#
# This class mounts specified device to specified location
# and takes backups to the destination once a day.
#
# === Parameters
#
# [*backup_from*]      - The location where the backups are wanted from.
# [*mount_dest*]       - The destination where to mount specified device.
# [*dev*]              - The device to mount.
# [*backup_dest_dir*]  - The location where the backups are taken to.
# [*backup_dir_owner*] - The owner of the backup directory.
# [*backup_dir_perm*]  - The permissions to the backup directory.
#
# === Author
#
# Sampo Tyllilä <sampo.tyllila@gmail.com>
#
define rdiff::backup ( 
	$backup_from,
	$mount_dest, 
	$dev,
	$backup_dest_dir, 
	$backup_dir_owner = 'root',
	$backup_dir_perm  = '700'
) 	{

	include rdiff

	file { $mount_dest:
		ensure  => directory,
		replace => false,
	}

	mount { $mount_dest:
                device  => $dev,
                fstype  => 'auto',
                ensure  => mounted,
                options => 'defaults',
		atboot  => true,
                require => File[$mount_dest],
        }

        file { "${mount_dest}/${backup_dest_dir}":
                ensure  => directory,
                replace => false,
                owner   => $backup_dir_owner,
                group   => $backup_dir_owner,
                mode    => $backup_dir_perm,
		require => Mount[$mount_dest],
        }

	schedule { 'backup':
		range  => "2 - 4",
		period => daily,
		repeat => 1,
	}

	exec { "/usr/bin/rdiff-backup -b ${backup_from} ${mount_dest}/${backup_dest_dir}":
		schedule => 'backup',
	}
		 
	exec { "/usr/bin/rdiff-backup --remove-older-than 6M ${mount_dest}/${backup_dest_dir}":
		schedule => 'backup',
	}

}
